import { UserConfig, ScopesType } from 'cz-git';
export { ScopesType } from 'cz-git';

/**
 * 用户自己额外配置的范围项 拆分出表述文本的配置项
 * @description
 */
type ScopesItemWithDesc = {
    /** 输入时的提示词 */
    code: string;
    /** 最终显示在 git commit 的文本 */
    value: string;
    /** 表述文本 */
    desc: string;
};

/**
 * ScopesType 的数组配置项
 * @description
 * 为了约束配置范围
 */
type ScopesTypeItem = Exclude<ScopesType[number], string>;

/**
 * 用户配置项
 * @description
 * 可以是 ScopesTypeItem 或 ScopesItemWithDesc
 */
type UserScopesItem = ScopesTypeItem | ScopesItemWithDesc;
/**
 * 获取用户配置
 * @description
 * 可以根据用户提供的范围，补充范围配置
 *
 * 其范围配置数组，默认排序到最前面，其次才是自动识别到包范围。
 */
declare function getUserConfig(
/** 用户提供的范围配置 */
userScopes?: UserScopesItem[]): UserConfig;
declare const _default: UserConfig;

export { type ScopesItemWithDesc, type ScopesTypeItem, type UserScopesItem, _default as default, getUserConfig };
